@@ -49,6 +49,14 @@
 
 #include "javacodegen.h"
 
+#include "goipgoto.h"
+
+#include "mltable.h"
+#include "mlftable.h"
+#include "mlflat.h"
+#include "mlfflat.h"
+#include "mlgoto.h"
+
 #include "rubytable.h"
 #include "rubyftable.h"
 #include "rubyflat.h"
@@ -145,6 +153,35 @@ CodeGenData *cdMakeCodeGen( const char *sourceFileName, const char *fsmName, ost
 		}
 		break;
 
+	case HostLang::D2:
+		switch ( codeStyle ) {
+		case GenTables:
+			codeGen = new D2TabCodeGen(out);
+			break;
+		case GenFTables:
+			codeGen = new D2FTabCodeGen(out);
+			break;
+		case GenFlat:
+			codeGen = new D2FlatCodeGen(out);
+			break;
+		case GenFFlat:
+			codeGen = new D2FFlatCodeGen(out);
+			break;
+		case GenGoto:
+			codeGen = new D2GotoCodeGen(out);
+			break;
+		case GenFGoto:
+			codeGen = new D2FGotoCodeGen(out);
+			break;
+		case GenIpGoto:
+			codeGen = new D2IpGotoCodeGen(out);
+			break;
+		case GenSplit:
+			codeGen = new D2SplitCodeGen(out);
+			break;
+		}
+		break;
+
 	default: break;
 	}
 
@@ -165,6 +202,27 @@ CodeGenData *javaMakeCodeGen( const char *sourceFileName, const char *fsmName, o
 	return codeGen;
 }
 
+/* Invoked by the parser when a ragel definition is opened. */
+CodeGenData *goMakeCodeGen( const char *sourceFileName, const char *fsmName, ostream &out )
+{
+	CodeGenData *codeGen;
+
+	switch ( codeStyle ) {
+	case GenIpGoto:
+		codeGen = new GoIpGotoCodeGen(out);
+		break;
+	default:
+		cerr << "I only support the -G2 output style for Go.  Please "
+			"rerun ragel including this flag.\n";
+		exit(1);
+	}
+
+	codeGen->sourceFileName = sourceFileName;
+	codeGen->fsmName = fsmName;
+
+	return codeGen;
+}
+
 /* Invoked by the parser when a ragel definition is opened. */
 CodeGenData *rubyMakeCodeGen( const char *sourceFileName, const char *fsmName, ostream &out )
 {
@@ -242,6 +300,38 @@ CodeGenData *csharpMakeCodeGen( const char *sourceFileName, const char *fsmName,
 	return codeGen;
 }
 
+/* Invoked by the parser when a ragel definition is opened. */
+CodeGenData *ocamlMakeCodeGen( const char *sourceFileName, const char *fsmName, ostream &out )
+{
+	CodeGenData *codeGen = 0;
+
+	switch ( codeStyle ) {
+	case GenTables:
+		codeGen = new OCamlTabCodeGen(out);
+		break;
+	case GenFTables:
+		codeGen = new OCamlFTabCodeGen(out);
+		break;
+	case GenFlat:
+		codeGen = new OCamlFlatCodeGen(out);
+		break;
+	case GenFFlat:
+		codeGen = new OCamlFFlatCodeGen(out);
+		break;
+	case GenGoto:
+		codeGen = new OCamlGotoCodeGen(out);
+		break;
+	default:
+		cerr << "I only support the -T0 -T1 -F0 -F1 and -G0 output styles for OCaml.\n";
+		exit(1);
+	}
+
+	codeGen->sourceFileName = sourceFileName;
+	codeGen->fsmName = fsmName;
+
+	return codeGen;
+}
+
 
 CodeGenData *makeCodeGen( const char *sourceFileName, const char *fsmName, ostream &out )
 {
@@ -252,12 +342,18 @@ CodeGenData *makeCodeGen( const char *sourceFileName, const char *fsmName, ostre
 		cgd = cdMakeCodeGen( sourceFileName, fsmName, out );
 	else if ( hostLang == &hostLangD )
 		cgd = cdMakeCodeGen( sourceFileName, fsmName, out );
+	else if ( hostLang == &hostLangD2 )
+		cgd = cdMakeCodeGen( sourceFileName, fsmName, out );
+	else if ( hostLang == &hostLangGo )
+		cgd = goMakeCodeGen( sourceFileName, fsmName, out );
 	else if ( hostLang == &hostLangJava )
 		cgd = javaMakeCodeGen( sourceFileName, fsmName, out );
 	else if ( hostLang == &hostLangRuby )
 		cgd = rubyMakeCodeGen( sourceFileName, fsmName, out );
 	else if ( hostLang == &hostLangCSharp )
 		cgd = csharpMakeCodeGen( sourceFileName, fsmName, out );
+	else if ( hostLang == &hostLangOCaml )
+		cgd = ocamlMakeCodeGen( sourceFileName, fsmName, out );
 	return cgd;
 }
 
@@ -268,12 +364,18 @@ void lineDirective( ostream &out, const char *fileName, int line )
 			cdLineDirective( out, fileName, line );
 		else if ( hostLang == &hostLangD )
 			cdLineDirective( out, fileName, line );
+		else if ( hostLang == &hostLangD2 )
+			cdLineDirective( out, fileName, line );
+		else if ( hostLang == &hostLangGo )
+			gothicLineDirective( out, fileName, line );
 		else if ( hostLang == &hostLangJava )
 			javaLineDirective( out, fileName, line );
 		else if ( hostLang == &hostLangRuby )
 			rubyLineDirective( out, fileName, line );
 		else if ( hostLang == &hostLangCSharp )
 			csharpLineDirective( out, fileName, line );
+		else if ( hostLang == &hostLangOCaml )
+			ocamlLineDirective( out, fileName, line );
 	}
 }
 
