@@ -93,9 +93,11 @@ struct InputData
 	void terminateAllParsers();
 
 	void cdDefaultFileName( const char *inputFile );
+	void goDefaultFileName( const char *inputFile );
 	void javaDefaultFileName( const char *inputFile );
 	void rubyDefaultFileName( const char *inputFile );
 	void csharpDefaultFileName( const char *inputFile );
+	void ocamlDefaultFileName( const char *inputFile );
 
 	void writeLanguage( std::ostream &out );
 	void writeXML( std::ostream &out );
